@@ -4,7 +4,7 @@
 #> open https://flavjack.github.io/inti/
 #> open https://flavjack.shinyapps.io/tarpuy/
 #> author .: Flavio Lozano-Isla (lozanoisla.com)
-#> date .: 2021-09-30
+#> date .: 2023-05-21
 # -------------------------------------------------------------------------
 
 # -------------------------------------------------------------------------
@@ -51,7 +51,7 @@ navbarPage(title = div(
 # Yupana Info -------------------------------------------------------------
 # -------------------------------------------------------------------------
 
-           tabPanel("Intro"
+           tabPanel("Intro", icon = icon("home") 
                     
                     , bs_theme_dependencies("flatly") #!
                     
@@ -175,7 +175,7 @@ navbarPage(title = div(
 
                              fluidRow(
 
-                               box(title = h5("Info")
+                               box(title = h5("Information")
                                    , width = 2
                                    , solidHeader = T,
 
@@ -192,7 +192,7 @@ navbarPage(title = div(
 
                                    textInput(inputId = "gsheet_design"
                                              , label = NULL
-                                             , value = "dsg"
+                                             , value = "design"
                                              , placeholder = "Sheet name"
                                    ),
 
@@ -204,21 +204,17 @@ navbarPage(title = div(
 
                                    textInput(inputId = "gsheet_varlist"
                                              , label = NULL
-                                             , value = "var"
+                                             , value = "traits"
                                              , placeholder = "Sheet name"
                                    ),
 
                                ),
 
-                               box(title = h5("Fieldbook")
+                               box(title = #h5("Fieldbook")
                                    , width = 2
                                    , solidHeader = T,
-
-                                   textInput(inputId = "gsheet_fb"
-                                             , label = NULL
-                                             , value = "fb"
-                                             , placeholder = "Sheet name"
-                                   ),
+                                   
+                                   #> gap()
 
                                ),
 
@@ -308,7 +304,7 @@ navbarPage(title = div(
                                   Si tienes muchas pestañas que dificultan tu trabajo, puedes ir ocultandolas (<em>click derecho en la pestaña > Ocultar hoja</em>).
                                   Al momento de usar la app puedes especificar qué hoja deseas utilizar y la app extrae la información de la hoja indicada.
                                   <li>Si deseas analizar los datos experimentales de tu proyecto, puedes usar la app Yupana:
-                                  <a href="https://flavjack.shinyapps.io/yupanapro/">https://flavjack.shinyapps.io/yupanapro/</a>
+                                  <a href="https://flavjack.shinyapps.io/yupana/">https://flavjack.shinyapps.io/yupana/</a>
                                   </li>
                                   </ul>
                                   <p>
@@ -343,7 +339,7 @@ navbarPage(title = div(
 
                              <div style="display:inline-block; width:100%">
                              <p style="text-align:center">
-                             <a target="_blank" href="https://flavjack.shinyapps.io/yupanapro/">
+                             <a target="_blank" href="https://flavjack.shinyapps.io/yupana/">
                              <img src="https://flavjack.github.io/inti/img/yupana.png" style="height:80px" title="yupana"></a>
                              <span style="display:block;"><small>Yupana</small></span>
                              </p></div>
@@ -371,7 +367,7 @@ navbarPage(title = div(
             
            ),
 
-           tabPanel("Plex",
+           tabPanel(div(h5(icon("seedling"),  "Plex")),
 
                     # Yupana Fieldbook --------------------------------------------------------
                     # -------------------------------------------------------------------------
@@ -394,12 +390,14 @@ navbarPage(title = div(
                                                               , "fieldbook"
                                                               , "album"
                                                               , "github"
+                                                              , "gdocs"
                                                               )
                                                 , selected = c("manager"
                                                                , "location"
                                                                , "dates"
                                                                , "about"
                                                                , "environment"
+                                                               , "gdocs"
                                                                )
                              ),
 
@@ -422,11 +420,6 @@ navbarPage(title = div(
                                        , width = "100%"
                                        , value = NA
                                        , placeholder = "sheet name"
-                             ),
-
-                             actionButton(inputId = "plex_generate"
-                                          , label = "Generate"
-                                          , class = "btn btn-success"
                              )
 
                              ),
@@ -485,6 +478,7 @@ navbarPage(title = div(
                                                                       , "Field"
                                                                       , "Greenhouse"
                                                                       , "Laboratory"
+                                                                      , "Others"
                                                                       )
                                                         , width = "100%"
                                                         )
@@ -561,6 +555,17 @@ navbarPage(title = div(
                                                         , value = NA
                                               )
 
+                             ),
+                             
+                             conditionalPanel(condition =  ' input["plex_fields"].includes("gdocs") ',
+                                              
+                                              textInput(inputId = "plex_gdocs"
+                                                        , label = "Google Docs"
+                                                        , width = "100%"
+                                                        , placeholder = "url or link"
+                                                        , value = NA
+                                              )
+                                              
                              )
                       ),
 
@@ -608,7 +613,6 @@ navbarPage(title = div(
                              
                              fluidRow(
                                
-                               
                                column(7,
                                       
                                       numericInput(
@@ -630,18 +634,35 @@ navbarPage(title = div(
                                                    )
                                       )
                                ),
-
-                             uiOutput("plex_design"),
+                             
+                             fluidRow( 
+                               
+                               column(7,
+                                      
+                                      uiOutput("plex_design")
+                                      
+                                      ),
+                               
+                               column(5,
+                                      
+                                      selectizeInput(
+                                        inputId = "plex_zigzag",
+                                        label = "Zigzag",
+                                        choices = c("FALSE", "TRUE")
+                                      )
+                               ),
+                               
+                               
+                               ), 
                              
                              fluidRow(
 
                                column(6,
                                       
                                       numericInput(inputId = "plex_serie"
-                                                   , label = "Plot digits"
-                                                   , value = 2
-                                                   , max = 3
-                                                   , min = 1
+                                                   , label = "Plots serie"
+                                                   , value = 100
+                                                   , min = 100
                                                    )
                                       
                                       ),
@@ -655,19 +676,27 @@ navbarPage(title = div(
                                                    )
                                       
                                       )
+                               ),
+                             
+                             br(),
+                             
+                             fluidRow(
+                               
+                               column(12,
+                                      
+                                      uiOutput("plex_sheets2create"),
+
+                               ),
+                                      
+                               
+                               column(12,
+                                      
+                                      actionButton(inputId = "plex_generate"
+                                                   , label = "Generate"
+                                                   , class = "btn btn-success"
+                                                   )
                                )
-                             
-                             
-
-                             
-                             
-
-
-
-
-
-
-
+                             )
                              
                              )
                       )
@@ -677,7 +706,7 @@ navbarPage(title = div(
 
            ),
 
-           tabPanel("Fieldbook",
+           tabPanel(div(h5(icon("book"), "Fieldbook")),
 
                     fluidRow(
 
@@ -717,10 +746,9 @@ navbarPage(title = div(
                                column(6,
                                       
                                       numericInput(inputId = "design_serie"
-                                                   , label = "Plot digits"
-                                                   , value = 2
-                                                   , max = 3
-                                                   , min = 1
+                                                   , label = "Plots serie"
+                                                   , value = 100
+                                                   , min = 0
                                                    ),
                                       
                                       ),
@@ -749,21 +777,38 @@ navbarPage(title = div(
                                
                                column(6,
                                       
-                                      radioButtons(inputId = "export_design_overwrite"
-                                                 , label = "Overwrite"
-                                                 , inline = TRUE
-                                                 , choices = c("no", "yes")
-                                                 )
+                                      selectInput(inputId = "design_zigzag"
+                                                  , label = "Zigzag"
+                                                  , choices = c("FALSE",  "TRUE")
+                                      )
+                               ),
+                               
+                               column(6,
+                                      
+                                      textInput(inputId = "fb2export"
+                                                , label = "Sheet export"
+                                                , placeholder = "sheet name"
+                                                , value = "fb"
                                       ),
+                                      
+                               ),
                                
                                column(6,
                                       
                                       actionButton(inputId = "export_design"
                                                    , label = "Generate"
                                                    , class = "btn btn-success"
-                                                   , width = "100%"
                                                    )
+                                      ),
+                               
+                               column(6,
+                                      
+                                      radioButtons(inputId = "export_design_overwrite"
+                                                   , label = "Overwrite"
+                                                   , inline = TRUE
+                                                   , choices = c("no", "yes")
                                       )
+                               ),
                                
                                ),
                              
@@ -785,7 +830,7 @@ navbarPage(title = div(
 
            ),
 
-tabPanel("Sketch",
+tabPanel(div(h5(icon("pen-ruler"), "Sketch")) ,
 
          fluidRow(
 
@@ -800,6 +845,9 @@ tabPanel("Sketch",
                                , inline = TRUE
                                , selected = "Sketch"
                                ),
+                  
+                  
+                  uiOutput("sketch_sheets"), 
 
                   uiOutput("sketch_options"),
 
@@ -822,8 +870,84 @@ tabPanel("Sketch",
            ),
 
 
+         ),
+
+
+# connect -----------------------------------------------------------------
+# -------------------------------------------------------------------------
+
+tabPanel(div(h5(icon("plug-circle-check"), "Mobile")),
+         
+         fluidRow(
+           
+           column(2,
+                  
+                  h5(icon("mobile-screen-button"), "Field Book app"),
+                  
+                  br(),
+                  
+                  radioButtons(inputId = "connection_sheet_preview"
+                               , label = h5(icon("magnifying-glass"), "Preview") 
+                               , choices = c("Traits"
+                                             , "Field Book")
+                               , inline = TRUE
+                               , selected = "Traits"
+                  ),
+                  
+                  fluidRow(
+                    
+                    h5(icon("wheat-awn"), "Traits"),
+                    
+                    uiOutput("connection_sheet_traits"),
+                    
+                  ),
+                  
+                  fluidRow(
+                    
+                    h5(icon("book"), "Field Book"),
+                    
+                    uiOutput("connection_sheet_fieldbook"),
+                    
+                    uiOutput("connection_fieldbook_lastfactor"),
+                    
+                  ),
+                  
+                  br(),
+                  
+                  fluidRow(
+                    
+                    h5(icon("cloud-arrow-down"), "Download Files"),
+                    
+                    column(6,
+                           
+                           uiOutput("connection_traits_download"),
+                           
+                           ),
+                    
+                    column(6,
+                           
+                           uiOutput("connection_fieldbook_download"),
+                           
+                    ),
+                    
+                  ),
+                  
+                  
+           ),
+           
+           column(10,
+                  
+                  uiOutput("connection_sheet_preview"),
+                  
+                  br(),
+                  br()
+                  
+           )
+           
          )
 
+)
+
 # Tarpuy end code ---------------------------------------------------------
 # -------------------------------------------------------------------------
 
